# Copyright 2023 (c) Anna Schumaker.
"""The `xfstestsdb xunit` command."""
import argparse
from .. import commands
from .. import sqlite
from . import delete
from . import gc
from . import list
from . import properties
from . import read
from . import rename


class Command(commands.Command):
    """The `xfstestsdb xunit` command."""

    def __init__(self, subparser: argparse.Action,
                 sql: sqlite.Connection) -> None:
        """Set up the xunit command."""
        super().__init__(subparser, sql, "xunit",
                         help="xfstestsdb xunit commands")
        self.subparser = self.parser.add_subparsers(title="xunit commands")
        self.commands = {"delete": delete.Command(self.subparser, sql),
                         "gc": gc.Command(self.subparser, sql),
                         "list": list.Command(self.subparser, sql),
                         "properties": properties.Command(self.subparser, sql),
                         "read": read.Command(self.subparser, sql),
                         "rename": rename.Command(self.subparser, sql)}

    def do_command(self, args: argparse.Namespace) -> None:
        """Print help text for the xunit subcommand."""
        self.parser.print_usage()
